pub fn dedup_errors(errs: &[ParseError]) -> Vec<ParseError>Expand description
Deduplicate errors by span start position.
If two errors start at the same position, only the first is kept.
pub fn dedup_errors(errs: &[ParseError]) -> Vec<ParseError>Deduplicate errors by span start position.
If two errors start at the same position, only the first is kept.