pub fn error_source_text<'a>(err: &ParseError, source: &'a str) -> &'a strExpand description
Extract the source text covered by the error span.
pub fn error_source_text<'a>(err: &ParseError, source: &'a str) -> &'a strExtract the source text covered by the error span.