pub fn errors_have_same_message(a: &LocatedError, b: &LocatedError) -> boolExpand description
Checks if two errors have the same message after normalisation.
pub fn errors_have_same_message(a: &LocatedError, b: &LocatedError) -> boolChecks if two errors have the same message after normalisation.