Module functions

Module functions 

Auto-generated module

🤖 Generated with SplitRS

Functions

build_cache_key
Build a simple cache key from multiple components.
classify_cache_entry
Classify a cache entry into a tier based on access frequency.
combined_hash
Combined hash: mixes FNV-1a and DJB2.
compute_checksum
Compute checksum.
djb2_hash
DJB2 hash for expressions.
estimate_string_memory
Estimate memory usage of a cached string in bytes.
fnv1a_hash
Deterministic FNV-1a hash.
hash_alpha_equiv
Checks if two expression strings are alpha-equivalent by their hashes.
mix_hashes
Mix two hashes.
validate_cache_integrity
Validate cache integrity.