pub fn parse_decl_str(source: &str) -> ParseResult<String>Expand description
Parse an OxiLean declaration from a source string.
Errors
Returns Err with a description if lexing or parsing fails.
pub fn parse_decl_str(source: &str) -> ParseResult<String>Parse an OxiLean declaration from a source string.
Returns Err with a description if lexing or parsing fails.