pub enum EditKind {
Unchanged,
Inserted,
Deleted,
Modified,
}Expand description
The kind of change that affected a declaration.
Variants
Unchanged
The declaration is unchanged between old and new.
Inserted
The declaration was inserted in the new sequence (not present in old).
Deleted
The declaration was deleted from the old sequence (not present in new).
Modified
Same name + kind but the body changed.