pub struct DeclEdit {
pub kind: EditKind,
pub old_idx: Option<usize>,
pub new_idx: Option<usize>,
pub fingerprint: DeclFingerprint,
}Expand description
A single entry in the diff edit script produced by diff_modules.
Fields
kind: EditKindKind of change.
old_idx: Option<usize>Index in the old declaration sequence, or None for Inserted.
new_idx: Option<usize>Index in the new declaration sequence, or None for Deleted.
fingerprint: DeclFingerprintFingerprint of the “surviving” declaration:
Unchanged,Inserted,Modified→ fingerprint of the new decl.Deleted→ fingerprint of the old decl.