pub struct IndentLevel {
pub spaces: usize,
pub tabs: usize,
}Expand description
Represents an indentation level as a mix of spaces and tabs.
Fields
spaces: usizetabs: usizeImplementations
Sourceimpl IndentLevel
impl IndentLevel
pub fn new(spaces: usize, tabs: usize) -> Self
Sourcepub fn total_width(&self, tab_width: usize) -> usize
pub fn total_width(&self, tab_width: usize) -> usize
Total width in columns, using the given tab width.
Sourcepub fn is_deeper_than(&self, other: &IndentLevel, tab_width: usize) -> bool
pub fn is_deeper_than(&self, other: &IndentLevel, tab_width: usize) -> bool
Returns true if this level is strictly deeper than other.