Module functions

Module functions 

Auto-generated module

🤖 Generated with SplitRS

Functions

apply_substitutions
Apply a list of substitutions to a template string.
count_macro_invocations
Count macro invocations in a source string.
expand_template
Expand a macro template with bindings.
expand_template_ext
Expand a simple macro template with variable substitutions.
match_pattern
Match a macro pattern against input tokens.
parse_simple_template_ext
Parse a simple macro template string into nodes.
strip_macro_invocations
Strips macro invocations from a source string (very simplified).
substitute
Substitute bindings into a template to produce expanded tokens.
try_match_rule
Try to match a macro rule’s pattern against input tokens.