match_pattern

Function match_pattern 

pub fn match_pattern(
    pattern: &[MacroToken],
    input: &[Token],
) -> Option<Vec<(String, Vec<Token>)>>
Match a macro pattern against input tokens.

Returns a map from variable names to the tokens they matched, or None if the pattern does not match.