Module functions

Module functions 

Auto-generated module

🤖 Generated with SplitRS

Functions

all_patterns
Returns all notation patterns in a registry as strings.
compare_prec
A precedence-based comparison between two operators.
count_placeholders
Counts the number of placeholder slots _ in a notation pattern.
find_conflicts
Find conflicts in a notation registry.
fixity_to_kind
Convert a Fixity to the corresponding NotationKind.
kind_to_fixity
Convert a NotationKind to a Fixity (where applicable).
left_assoc_rules
Returns all left-associative notation rules in a registry.
make_infix
Build a simple infix notation entry from symbol, precedence, associativity.
make_postfix
Build a simple postfix notation entry.
make_prefix
Build a simple prefix notation entry.
merge_registries
Merge two notation registries.
notation_rule_count
Returns the total number of notation rules registered.
parse_notation_pattern
Parse a notation pattern string into parts.
parse_notation_pattern_ext
Parse a notation pattern into token kinds (extended variant).
registry_has_pattern
Returns true if the registry contains a rule for the given pattern.
registry_is_empty
Returns true if a registry is empty.
right_assoc_rules
Returns all right-associative notation rules in a registry.
rules_in_prec_range
Returns rules with precedence in a given range.
same_pattern
Returns true if two notation rules have the same pattern.
sorted_patterns
Returns all notation rule patterns as a sorted vector.
unique_patterns
Returns all unique patterns across a list of registries.
validate_notation
Validates that a notation pattern and expansion have consistent hole counts.