pub fn registry_has_pattern(reg: &NotationRegistry, pattern: &str) -> boolExpand description
Returns true if the registry contains a rule for the given pattern.
pub fn registry_has_pattern(reg: &NotationRegistry, pattern: &str) -> boolReturns true if the registry contains a rule for the given pattern.