pub fn same_pattern(a: &NotationRule, b: &NotationRule) -> boolExpand description
Returns true if two notation rules have the same pattern.
pub fn same_pattern(a: &NotationRule, b: &NotationRule) -> boolReturns true if two notation rules have the same pattern.