Module types

Module types 

Auto-generated module

🤖 Generated with SplitRS

Structs

ArrayPattern
Array/list pattern: [x, y, z] or [x, ..., z]
AsPattern
As-pattern: pat @ name
CaseBranch
A branch in a case tree switch.
ConstructorInfo
Information about a single constructor.
InaccessiblePattern
Inaccessible pattern: .(_) - pattern that can’t be matched
MatchArmExt
A pattern match arm.
MatchClause
A match clause with a pattern and a body.
PatternBinding
A variable binding in a pattern match.
PatternCoverage
Pattern coverage information
PatternCoverageExt
A pattern coverage checker (simplified).
PatternMatrixRow
A pattern matrix row (for exhaustiveness checking).
PatternRenamer
A pattern transformer that applies renaming to variable patterns.
PatternRow
A row in the pattern matrix.
SpecializedPattern
Pattern specialization result
TypeConstructors
Known constructors for exhaustiveness checking.

Enums

CaseTree
Result of pattern compilation.
PatternTagExt
A pattern type tag for classification.