is_complete

Function is_complete 

pub fn is_complete(input: &str) -> bool
Check if input is a complete statement.

Returns true when all brackets ((), [], {}) are balanced and no depths have gone negative (which would indicate a syntax error in the input so far).