Module types

Module types 

Auto-generated module

🤖 Generated with SplitRS

Structs

AliasRegistry
A REPL alias registry.
CommandAlias
A REPL command alias: maps a short name to a full command string.
CommandHistory
Command history for the REPL.
CommandTally
Tally of REPL command types seen during a session.
CompletionItem
A REPL completion item.
ConfigurableReplParser
Configurable REPL parser.
EventLog
A REPL event log that records all events.
FilterPipeline
A pipeline of input filters.
InputSplitter
An input splitter that breaks raw REPL input into logical lines, handling multi-line continuation (-- comments, (, begin, etc.).
LowercaseCommandFilter
An input filter that lowercases command keywords.
MultilineState
State of multi-line input accumulation.
NoopListener
A no-op REPL event listener.
OptionStore
A key-value option store for REPL session options.
ReplCompleter
A REPL completer that provides completions for a given prefix.
ReplFormatter
REPL output formatter.
ReplHistory
A REPL session history.
ReplHistoryEntry
A REPL session history entry.
ReplOptions
Options for REPL behavior.
ReplParser
REPL parser for parsing REPL-specific commands.
ReplParserConfig
Configuration for ReplParser.
ReplSession
A REPL session that tracks history, options, and statistics.
ReplStats
Statistics about REPL session.
StripSemicolonFilter
An input filter that strips trailing semicolons.

Enums

CompletionKind
The kind of a completion item.
ExtendedReplCommand
Extended REPL command including option management and history.
ReplCommand
REPL command type.
ReplEvent
A REPL event emitted by the session.
ReplInputKind
A REPL input classifier.
ReplMode
A REPL mode that controls what kinds of input are accepted.
ReplOption
A REPL session option that can be toggled.