pub struct PrefixComparator<'a> { /* private fields */ }Expand description
A comparator that tracks the best matching prefix between two strings.
Implementations
Sourceimpl<'a> PrefixComparator<'a>
impl<'a> PrefixComparator<'a>
Sourcepub fn common_prefix_len(&self) -> usize
pub fn common_prefix_len(&self) -> usize
Returns the length of the longest common prefix.
Sourcepub fn common_prefix(&self) -> &'a str
pub fn common_prefix(&self) -> &'a str
Returns the common prefix as a string slice of left.