Module functions

Module functions 

Functions for source map construction and querying.

Functions

merge_spans
Merge two spans into the smallest span that contains both.
span_contains
Returns true if inner is entirely contained within outer.