Module functions

Module functions 

Auto-generated module

🤖 Generated with SplitRS

Functions

all_orig_offsets
Returns all original offsets in a source map.
count_to_orig
Returns the number of mappings that map to a specific original offset.
covers_gen_offset
Returns true if a source map covers a generated offset.
diff_mappers
Compare two BidiMappers and return a diff.
filter_gen_range
Filters a source map to only entries where the generated offset is >= lo and < hi.
format_map_entry_json
A source map entry formatter (JSON-like).
is_injective
Returns true if a sorted source map has no duplicate gen offsets.
is_sorted_ascending
Returns true if all generated offsets in the map are in ascending order.
max_gen_offset
Returns the maximum generated offset in a source map, if any.
merge_sorted_maps
Merges two sorted source maps.
min_gen_offset
Returns the minimum generated offset in a source map, if any.
total_mappings
Returns the total number of mappings in a sorted source map.