pub fn max_gen_offset(m: &SortedSourceMap) -> Option<usize>Expand description
Returns the maximum generated offset in a source map, if any.
pub fn max_gen_offset(m: &SortedSourceMap) -> Option<usize>Returns the maximum generated offset in a source map, if any.