pub fn min_gen_offset(m: &SortedSourceMap) -> Option<usize>Expand description
Returns the minimum generated offset in a source map, if any.
pub fn min_gen_offset(m: &SortedSourceMap) -> Option<usize>Returns the minimum generated offset in a source map, if any.