pub struct SourceEntry {
pub span: Span,
pub kind: EntryKind,
pub name: Option<String>,
pub ty_info: Option<String>,
}Expand description
A single entry in the source map.
Fields
span: SpanSource span for this entry.
kind: EntryKindWhat kind of entry this is.
name: Option<String>Optional name associated with this entry.
ty_info: Option<String>Optional type information as a display string.
Implementations
Sourceimpl SourceEntry
impl SourceEntry
Sourcepub fn with_name(span: Span, kind: EntryKind, name: &str) -> Self
pub fn with_name(span: Span, kind: EntryKind, name: &str) -> Self
Create a source entry with a name.
Sourcepub fn with_name_and_type(
span: Span,
kind: EntryKind,
name: &str,
ty: &str,
) -> Self
pub fn with_name_and_type( span: Span, kind: EntryKind, name: &str, ty: &str, ) -> Self
Create a source entry with name and type info.
Sourcepub fn contains_offset(&self, offset: usize) -> bool
pub fn contains_offset(&self, offset: usize) -> bool
Check whether a byte offset falls within this entry’s span.