SourceMapBuilder

Struct SourceMapBuilder 

pub struct SourceMapBuilder { /* private fields */ }
Builder for constructing a SourceMap during parsing.

Implementations

Source

impl SourceMapBuilder

pub fn new(source: &str) -> Self

Create a new builder for the given source text.

pub fn add_entry(&mut self, span: Span, kind: EntryKind, name: Option<String>)

Add an arbitrary entry to the source map.

pub fn add_entry_with_type( &mut self, span: Span, kind: EntryKind, name: Option<String>, ty_info: String, )

Add an entry with type information.

pub fn add_definition(&mut self, span: Span, name: &str)

Add a definition entry.

pub fn add_definition_with_type( &mut self, span: Span, name: &str, ty_info: &str, )

Add a definition entry with type info.

pub fn add_reference(&mut self, span: Span, name: &str)

Add a reference entry.

pub fn add_binder(&mut self, span: Span, name: &str)

Add a binder entry.

pub fn add_constructor(&mut self, span: Span, name: &str)

Add a constructor entry.

pub fn add_keyword(&mut self, span: Span)

Add a keyword entry.

pub fn add_literal(&mut self, span: Span)

Add a literal entry.

pub fn add_operator(&mut self, span: Span, symbol: &str)

Add an operator entry.

pub fn add_comment(&mut self, span: Span)

Add a comment entry.

pub fn add_doc_comment(&mut self, span: Span, text: &str)

Add a doc comment entry.

pub fn add_tactic(&mut self, span: Span, name: &str)

Add a tactic entry.

pub fn add_pattern(&mut self, span: Span, name: Option<&str>)

Add a pattern entry.

pub fn add_type_annotation(&mut self, span: Span)

Add a type annotation entry.

pub fn add_semantic_token(&mut self, token: SemanticToken)

Add a pre-computed semantic token.

pub fn entry_count(&self) -> usize

Get the current number of entries.

pub fn build(self) -> SourceMap

Build the final SourceMap.

Entries are sorted by span start offset for efficient lookup.