Module token_utils

Module token_utils 

Utility functions for working with tokens.

Functions

char_count
Count the number of UTF-8 characters in a string slice.
escape_string
Escape a string for inclusion in an OxiLean string literal.
is_keyword
Returns true if the string is a reserved keyword in OxiLean.
is_valid_ident
Returns true if the given string slice is a valid OxiLean identifier.