pub enum TokenAnnotation {
BindingSite(String),
UseSite(String),
ResolvedName(String),
TacticStart,
TacticEnd,
ImplicitHole,
TypeSeparator,
}Expand description
Extra semantic information attached to a token.
Variants
BindingSite(String)
This token is an introduction site for the named variable.
UseSite(String)
This token is a use-site for the named variable.
ResolvedName(String)
This token’s identifier refers to a declaration with this qualified name.
TacticStart
This token starts a tactic block.
TacticEnd
This token ends a tactic block.
ImplicitHole
This token is a hole (implicit argument).
TypeSeparator
This token is a type annotation separator.