pub struct SurfaceIdent {
pub name: String,
pub span: ByteRange,
}Expand description
A raw identifier as it appears in source, together with its span.
Fields
name: StringThe identifier string.
span: ByteRangeSource span (byte offsets).
Implementations
Sourceimpl SurfaceIdent
impl SurfaceIdent
Sourcepub fn is_synthetic(&self) -> bool
pub fn is_synthetic(&self) -> bool
Whether the identifier was synthesized (not from real source).
Sourcepub fn is_anonymous(&self) -> bool
pub fn is_anonymous(&self) -> bool
Whether the identifier starts with an underscore.
Sourcepub fn is_qualified(&self) -> bool
pub fn is_qualified(&self) -> bool
Whether the identifier contains a dot (qualified name).
Sourcepub fn split_last(&self) -> Option<(&str, &str)>
pub fn split_last(&self) -> Option<(&str, &str)>
Split a qualified name at the last dot, if any.