Auto-generated module
🤖 Generated with SplitRS
Functions
- build_
cache_ key - Build a simple cache key from multiple components.
- classify_
cache_ entry - Classify a cache entry into a tier based on access frequency.
- combined_
hash - Combined hash: mixes FNV-1a and DJB2.
- compute_
checksum - Compute checksum.
- djb2_
hash - DJB2 hash for expressions.
- estimate_
string_ memory - Estimate memory usage of a cached string in bytes.
- fnv1a_
hash - Deterministic FNV-1a hash.
- hash_
alpha_ equiv - Checks if two expression strings are alpha-equivalent by their hashes.
- mix_
hashes - Mix two hashes.
- validate_
cache_ integrity - Validate cache integrity.