Auto-generated module
🤖 Generated with SplitRS
Structs
- Adaptive
Cache Entry - A cache entry with adaptive eviction support.
- Adaptive
LruCache - Adaptive LRU cache that self-tunes capacity based on hit rate.
- Alpha
EqCache - Alpha-equality cache.
- Bloom
Filter - Bloom filter.
- Bump
Allocator - Bump allocator for string storage.
- Cache
Coverage Report - Cache coverage report.
- Cache
Entry - Parse cache entry
- Cache
Health Report - Cache health report.
- Cache
KeyBuilder - Cache key builder using a chain of hash operations.
- Cache
Pressure Monitor - Cache pressure monitor.
- Cache
Prewarmer - Cache prewarmer.
- Cache
Report - Cache report with statistics.
- Cache
Warmup - Cache warmup configuration.
- Decl
Hash - Token sequence hash for declaration fingerprinting
- Expr
Diff Cache - An expression “diff” cache: stores the diff between two version of an expression.
- Expr
Location Index - Expression location index: maps hash to source locations.
- Expr
Pool - Expression pool with reference counting.
- Expr
Segment - Expression segment for incremental re-parsing.
- Global
Expr Table - Global expression table (hash-consing).
- Hash
Set64 - Hash set 64.
- Interned
Str - Interned string — lightweight identifier for a deduplicated string
- Interning
Stats - Interning statistics.
- LfuEviction
- LFU eviction policy.
- LruCache
- LRU cache implementation.
- Macro
Expansion Cache - Macro expansion cache.
- Macro
Expansion Entry - Memo
Entry - Memo
Table - Memo table for parser results.
- Multi
Level Cache - A multi-level cache: L1 (small, fast), L2 (larger, slower).
- Namespaced
Cache - Namespaced cache.
- Nesting
Depth Tracker - Nesting depth tracker.
- Parse
Cache - LRU parse cache for declaration re-use
- Parse
Cache Entry - Parse
Result Cache - Parse result cache.
- Persistent
Cache - A cache that serialises itself to a byte sequence for persistence.
- Policy
Cache - Policy cache with pluggable eviction.
- Rolling
Hash - Rolling hash.
- Segment
Table - Segment table for cache invalidation.
- String
Interner - String interner — maps strings to compact IDs
- String
Pool - String pool for deduplication.
- Subexpr
Frequency Map - Subexpression frequency map.
- Symbol
Interner - Interned symbol with kind.
- Token
Frequency Table - Token frequency table.
- Token
Window - A sliding window for recent token sequences.
- TtlEviction
- TTL eviction policy.
- TwoQueue
Cache - Two-queue cache.
- Type
Check Cache - Type check cache.
- Type
Check Result - Versioned
Cache - Versioned cache.
- Window
Cache - Window cache.
- Windowed
Cache Metrics - Windowed cache metrics.
Enums
- Cache
Priority - Priority levels for cache entries.
- Cache
Tier - Classify cache entry tier.
- Segment
Kind