Function parse_expr_str
Source pub fn parse_expr_str(source: &str) -> ParseResult<String>
Parse an OxiLean expression from a source string.
This is a convenience wrapper around the lexer and parser.
Errors
Returns Err with a description if lexing or parsing fails.
Example
ⓘlet expr = parse_expr_str("1 + 2")?;