Auto-generated module
🤖 Generated with SplitRS
Functions
- apply_
substitutions - Apply a list of substitutions to a template string.
- count_
macro_ invocations - Count macro invocations in a source string.
- expand_
template - Expand a macro template with bindings.
- expand_
template_ ext - Expand a simple macro template with variable substitutions.
- match_
pattern - Match a macro pattern against input tokens.
- parse_
simple_ template_ ext - Parse a simple macro template string into nodes.
- strip_
macro_ invocations - Strips macro invocations from a source string (very simplified).
- substitute
- Substitute bindings into a template to produce expanded tokens.
- try_
match_ rule - Try to match a macro rule’s pattern against input tokens.