Module system functions: path parsing, resolution, graph analysis.
Structs
- Module
Path Parse Error - Error returned when a module path string cannot be parsed.
Functions
- build_
module_ graph - Build a
ModuleGraphfrom all modules currently registered inregistry. - detect_
cycles - Detect all import cycles in
graph. - direct_
deps_ of - Return the direct dependencies of
moduleingraph. - parse_
import_ decl - Parse a single
importline. - parse_
imports - Extract all
importdeclarations from a source file. - topological_
sort - Produce a topological ordering of modules in
graphso that every module appears after all its dependencies. - transitive_
deps - Return all modules transitively reachable from
module(excluding itself).