Auto-generated module
๐ค Generated with SplitRS
Functions
- classify_
pattern_ ext - Classify a pattern string by its leading token.
- count_
all_ vars - A pattern variable counter.
- count_
pattern_ vars - A depth-first traversal of a pattern tree (string-based).
- ctor_
arity - Returns the arity of a constructor pattern (number of arguments).
- extract_
ctor_ name - Returns the constructor name from a pattern string.
- is_
ctor_ pattern - Returns true if a pattern string is a constructor application.
- is_
pair_ pattern - Returns true if a pattern is a pair pattern โ(a, b)โ.
- is_
wildcard_ pattern - Returns true if a pattern string is a wildcard.
- normalise_
or_ pattern - A pattern normaliser that sorts or-patterns.
- pattern_
depth - A pattern depth counter.
- pattern_
vars - Returns the variable names bound in a pattern string (simplified: lowercase idents).
- same_
ctor - Returns true if two patterns have the same structure (same ctor and arity).