Auto-generated module
🤖 Generated with SplitRS
Structs
- Array
Pattern - Array/list pattern:
[x, y, z]or[x, ..., z] - AsPattern
- As-pattern:
pat @ name - Case
Branch - A branch in a case tree switch.
- Constructor
Info - Information about a single constructor.
- Inaccessible
Pattern - Inaccessible pattern:
.(_)- pattern that can’t be matched - Match
ArmExt - A pattern match arm.
- Match
Clause - A match clause with a pattern and a body.
- Pattern
Binding - A variable binding in a pattern match.
- Pattern
Coverage - Pattern coverage information
- Pattern
Coverage Ext - A pattern coverage checker (simplified).
- Pattern
Matrix Row - A pattern matrix row (for exhaustiveness checking).
- Pattern
Renamer - A pattern transformer that applies renaming to variable patterns.
- Pattern
Row - A row in the pattern matrix.
- Specialized
Pattern - Pattern specialization result
- Type
Constructors - Known constructors for exhaustiveness checking.
Enums
- Case
Tree - Result of pattern compilation.
- Pattern
TagExt - A pattern type tag for classification.