Auto-generated module
🤖 Generated with SplitRS
Structs
- Alias
Registry - A REPL alias registry.
- Command
Alias - A REPL command alias: maps a short name to a full command string.
- Command
History - Command history for the REPL.
- Command
Tally - Tally of REPL command types seen during a session.
- Completion
Item - A REPL completion item.
- Configurable
Repl Parser - Configurable REPL parser.
- Event
Log - A REPL event log that records all events.
- Filter
Pipeline - A pipeline of input filters.
- Input
Splitter - An input splitter that breaks raw REPL input into logical lines,
handling multi-line continuation (
--comments,(,begin, etc.). - Lowercase
Command Filter - An input filter that lowercases command keywords.
- Multiline
State - State of multi-line input accumulation.
- Noop
Listener - A no-op REPL event listener.
- Option
Store - A key-value option store for REPL session options.
- Repl
Completer - A REPL completer that provides completions for a given prefix.
- Repl
Formatter - REPL output formatter.
- Repl
History - A REPL session history.
- Repl
History Entry - A REPL session history entry.
- Repl
Options - Options for REPL behavior.
- Repl
Parser - REPL parser for parsing REPL-specific commands.
- Repl
Parser Config - Configuration for ReplParser.
- Repl
Session - A REPL session that tracks history, options, and statistics.
- Repl
Stats - Statistics about REPL session.
- Strip
Semicolon Filter - An input filter that strips trailing semicolons.
Enums
- Completion
Kind - The kind of a completion item.
- Extended
Repl Command - Extended REPL command including option management and history.
- Repl
Command - REPL command type.
- Repl
Event - A REPL event emitted by the session.
- Repl
Input Kind - A REPL input classifier.
- Repl
Mode - A REPL mode that controls what kinds of input are accepted.
- Repl
Option - A REPL session option that can be toggled.