Utility functions for working with tokens.
Functions
- char_
count - Count the number of UTF-8 characters in a string slice.
- escape_
string - Escape a string for inclusion in an OxiLean string literal.
- is_
keyword - Returns
trueif the string is a reserved keyword in OxiLean. - is_
valid_ ident - Returns
trueif the given string slice is a valid OxiLean identifier.